@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Exporter 'import';
-our $VERSION    = 0.11;
+our $VERSION    = 0.12;
 
 use liberty;
 use Parse::Liberty::Constants qw($e $e2 %errors);
@@ -44,7 +44,7 @@ sub new {
 
 sub methods {
     my $self = shift;
-    return (join "\n", qw(library))."\n";
+    return (join "\n", qw(library write_library))."\n";
 }
 
 ################################################################################
@@ -610,6 +610,29 @@ Return value value (string)
         }
     }
 
+=head2 Using Parse::Liberty::Simple
+
+my $parser = new Parse::Liberty::Simple ("test.lib");
+
+print $parser->name; # library name
+
+my @attrs = $parser->attrs; # all library-level attributes
+my @attrs = $parser->attrs('date', '.*_unit');
+my $attr = $parser->attrs('date'); # object (print $attr->value)
+my $attr = $parser->attr('date'); # value of an attribute
+print $_->name.' | '.$_->value."\n" for @attrs;
+
+my @cells = $parser->cells; # all cell-type groups
+my @cells = $parser->cells('BUF2', 'DFF');
+my $cell = $parser->cells('INV3');
+print $cell->name; # cell name
+print $cell->attr('area');
+print $_->name for $cell->pins;
+
+my $pin = $cell->pins('Q.*');
+print $pin->name; # pin name
+print $pin->attr('direction');
+
 
 =head1 AUTHOR
 
@@ -618,7 +641,7 @@ Eugene Gagarin <mosfet07@ya.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013 Eugene Gagarin
+Copyright 2015 Eugene Gagarin
 
 This library is free software; you may redistribute it and/or modify
 it under the same terms as Perl itself.
